#! /bin/sh

# WWF toolkit - Installation - Copyright 2011 J.L. Bezemer
# You can redistribute this file and/or modify it under
# the terms of the GNU General Public License

#
# Returns non-zero when program found in $PATH, otherwise zero.
#

function installed {
  which $1 2> /dev/null | wc -l
}

#
# This function gets a .wwf document from the web and rips the banner.
#

function getbanner {
  URL[0]=http://www.saveaswwf.com/fileadmin/user_upload/Presse/Presseinfo_SAVE_AS_WWF_-_SAVE_A_TREE.wwf
  URL[1]=http://www.ecoxotic.com/community/wp-content/uploads/2010/12/WallMount_PanoramaInstructions.wwf
  URL[2]=http://www.ecoxotic.com/community/wp-content/uploads/2010/12/StandMount_Manual.wwf
  URL[3]=http://www.ecoxotic.com/community/wp-content/uploads/2010/12/Panorama36_Retro_Instructions-1.wwf
  URL[4]=http://www.fontblog.de/wp-content/uploads/2010/typosuenden.wwf
  URL[5]=http://www.spreeblick.com/wp-content/uploads/jmstv.wwf
  URL[6]=http://www.vinedesign.com.br/cv.wwf
  URL[7]=http://nikismeets.be/pdf/cv.wwf
  URL[8]=http://chriswi.be/pdf/christian_swinnen_cv.wwf
  URL[9]=http://www.thomaswuscher.com/agb.wwf
  URL[10]=http://www.gyonk.hu/onk/valasztas.wwf
  URL[11]=http://www.gyonk.hu/onk/hatarozat.wwf

  for wwf in 0 1 2 3 4 5 6 7 8 9 10 11
  do
    wget -q ${URL[$wwf]}; wget=$?
    if [ $wget -eq 0 ]; then
       document=`basename ${URL[$wwf]}`
       break;
    fi
  done

  if [ $wget -eq 0 ]; then
     echo "- Downloading document.."
  else
     echo "- Could not download document, aborting."
     exit
  fi

  pdftops -f `pdfinfo $document | grep Pages: | cut -f2 -d:` -level3 $document wwf.ps;

  if [ "$?" -eq 0 ]; then
     echo "- Cracking document.."
  else
     echo "- Could not convert document to Postscript, aborting."
     exit
  fi

  ps2pdf -dCompatibilityLevel=1.4 -dEmbedAllFonts=true wwf.ps wwf.pdf

  if [ "$?" -eq 0 ]; then
     echo "- Extracting WWF banner.."
  else
     echo "- Could not convert document to PDF, aborting."
     exit
  fi

  rm wwf.ps $document

  if [ "$?" -eq 0 ]; then
     echo "- Cleaning up.."
  else
     echo "- WARNING: Could not remove temporary files."
  fi
}

#
# This functions renames the internal banner so it can be installed.
#

function setbanner {
   cp banner.pdf wwf.pdf

   if [ "$?" -eq 0 ]; then
      echo "- Preparing alternate banner.."
   else
      echo "- Could not copy banner.pdf, aborting."
      exit
   fi
}

echo "** INSTALLING .wwf toolkit **"

if [ `installed pdftk` -eq 0 ]; then
   echo "- PDFtk not installed, aborting."
   exit
fi

if [ `installed ps2pdf` -eq 0 ]; then
   echo "- Ghostscript not installed, aborting."
   exit
fi

if [ `installed pdftops` -eq 0 ]; then
   echo "- Poppler tools not installed, aborting."
   exit
fi

if [ `installed kdialog` -eq 0 ]; then
   echo "- WARNING: KDialog not installed."
fi

if [ `installed zenity` -eq 0 ]; then
   echo "- WARNING: Zenity not installed."
fi

if [ `installed dialog` -eq 0 ]; then
   echo "- WARNING: Dialog not installed."
fi

if [ "$1" == "--nowwfbanner" ]; then
   setbanner
else
   if [ `installed wget` -eq 0 ]; then
      echo "- WARNING: WGet not installed, using alternate banner."
      setbanner
   else
      getbanner
   fi
fi

if [ `whoami` == "root" ]; then
   if [ -d /usr/share ]; then

      mkdir -p /usr/share/wwftk
      mv wwf.pdf /usr/share/wwftk

      if [ "$?" -eq 0 ]; then
         echo "- Installing banner.."
      else
         echo "- Could not install wwf.pdf, aborting."
         exit
      fi
   else
      echo "- Cannot locate /usr/share directory, aborting."
      exit
   fi

   if [ -d /usr/local/bin ]; then

      cp pdf2wwf wwf2pdf /usr/local/bin

      if [ "$?" -eq 0 ]; then
         echo "- Installing scripts.."
      else
         echo "- Could not install scripts, aborting."
         exit
      fi
   else
      echo "- Cannot locate /usr/local/bin directory, aborting."
      exit
   fi

else
   echo "- Only root can complete the installation, aborting."
   exit
fi

echo "** FINISHED **"
